module StubHubApi
  class Fulfillment < Base
    def upload_pdf(file, sale_id, options)
      doc       = post_multi_part_query_api("/fulfillment/pdf/v1/sale/#{sale_id}", options, StringIO.new(Base64.decode64(file)))
      fields    = %w(orderId row seatNo uploadStatus delivered)
      response  = {}
      doc.xpath("uploadPDFTicketToOrderResponse").each do |xml|
        fields.each do |field|
          response[field] = xml.at_xpath(field).content if xml.at_xpath(field).content
        end
      end
      response
    end

    def preload_pdf(file, listing_id, options)
      doc       = post_multi_part_query_api("/fulfillment/pdf/v1/listing/#{listing_id}", options, StringIO.new(Base64.decode64(file)))
      fields    = %w(listingId row seatNo uploadStatus preDelivered)
      response  = {}
      doc.xpath("uploadPDFTicketToListingResponse").each do |xml|
        fields.each do |field|
          response[field] = xml.at_xpath(field).content if xml.at_xpath(field).content
        end
      end
      response
    end

    def preload_pdf_json(listing_id, options, files)
      boundary = "------WebKitFormBoundary7MA4YWxkTrZu0gW"
      post_body = ""
      post_body << "#{boundary}\r\n"
      post_body << "Content-Disposition: form-data; name=\"listing\"\r\n\r\n"
      post_body << "#{options.to_json}\r\n"
      files.each do |file|
        post_body << "#{boundary}\r\n"
        post_body << "Content-Disposition: form-data; name=\"#{file[:file_name]}\"; filename=\"#{file[:file_name]}.pdf\"\r\n"
        post_body << "Content-Type: application/pdf\r\n\r\n"
        post_body << ""
        post_body << ""
        post_body << open(file[:file]).read
        post_body << ""
        post_body << "\r\n"
      end
      post_body << "\r\n"
      post_body << "#{boundary}--\r\n"
      post_multi_pdfs_json_query_api("/inventory/listings/v1/#{listing_id}/pdfs", post_body)
    end


    def label_for(options)
      post_query_api("/fulfillment/shipping/v1/labels", true, options)
    end


    def get_label_for(options)
      get_query_api("/fulfillment/shipping/v1/labels", options)
    end

    def confirm_transfer_sales(sale_id)
      post_query_api("/fulfillment/delivery/v1/sale/#{sale_id}/confirmation", false)
    end

    def upload_barcode(options)
      post_query_api("/fulfillment/barcode/v1/order", true, options)
    end


  end
end
